@@ -1,4 +1,4 @@
-mod asyncapi;
+mod api;
 mod channel;
 mod channel_binding;
 mod components;
@@ -21,6 +21,7 @@ mod server_binding;
 mod tag;
 mod variant_or;
 
+pub use api::AsyncAPI;
 pub use channel::Channel;
 pub use channel_binding::ChannelBinding;
 pub use components::Components;
@@ -30,6 +31,7 @@ pub use example::Example;
 pub use external_documentation::ExternalDocumentation;
 pub use info::{Contact, Info, License};
 pub use message::Message;
+pub use message_binding::MessageBinding;
 pub use message_trait::MessageTrait;
 pub use operation_binding::OperationBinding;
 pub use operation_trait::OperationTrait;
